Quickstart
==========

Installation
------------

pyDARTlab can be installed through pip.  We recommend installing pydartdiags in a virtual enviroment:

.. code-block :: text

    python3 -m venv dartlab
    source dartlab/bin/activate
    pip install pydartlab
